@@ -24,6 +24,7 @@
 #include "strace.h"
 #include "translate.h"
 #include "ptranslate.h"
+#include "ttranslate.h"
 #include "hierpack.h"
 #include "analyzer.h"
 
@@ -31,6 +32,8 @@
 #define strcasecmp _stricmp
 #endif
 
+void UpdateTraceSelection(Trptr t);
+
 
 /*
  * extract last n levels of hierarchy
@@ -232,6 +235,13 @@ if(GLOBALS->default_flags & TR_PTRANSLATED)
 	t->p_filter = GLOBALS->current_translate_proc;
 	}
 
+/* NOT an else! */
+if(GLOBALS->default_flags & TR_TTRANSLATED)
+	{
+	t->t_filter = GLOBALS->current_translate_ttrans;
+	traverse_vector_nodes(t);
+	}
+
  if (IsGroupBegin(t)) {
    GLOBALS->group_depth = GLOBALS->group_depth + 1;
  }
@@ -549,7 +559,7 @@ int AddVector(bvptr vec, char *aliasname)
     if( t == NULL )
       {
 	fprintf( stderr, "Out of memory, can't add %s to analyzer\n",
-	  vec->name );
+	  vec->bvname );
 	return( 0 );
       }
 
@@ -560,7 +570,7 @@ int AddVector(bvptr vec, char *aliasname)
       }
     else
       {
-	t->name = vec->name;
+	t->name = vec->bvname;
       }
 
     if(GLOBALS->hier_max_level)
@@ -596,10 +606,33 @@ if(GLOBALS->strace_ctx->straces)
 
 if(t->vector)
       	{
-      	bvptr bv;
+      	bvptr bv, bv2;
 	int i;
 
 	bv=t->n.vec;
+	/* back out allocation to revert (if any) */
+        if(bv->transaction_cache)
+		{ 
+		t->n.vec = bv->transaction_cache;
+
+		while(bv)
+			{
+			bv2 = bv->transaction_chain;
+			if(bv->bvname) { free_2(bv->bvname); }
+
+	                for(i=0;i<bv->numregions;i++)
+				{
+	                        free_2(bv->vectors[i]);
+	                        }
+
+	                free_2(bv);
+			bv = bv2;
+			}			
+
+		bv=t->n.vec;
+                }
+
+	/* normal vector deallocation */
 	for(i=0;i<bv->numregions;i++)
 		{
 		if(bv->vectors[i]) free_2(bv->vectors[i]);
@@ -616,7 +649,7 @@ if(t->vector)
 		free_2(bv->bits);
 		}
 
-	if(bv->name) free_2(bv->name);
+	if(bv->bvname) free_2(bv->bvname);
       	if(t->n.vec) free_2(t->n.vec);
       	}
 	else
@@ -1215,22 +1248,11 @@ prev->t_next=NULL;
 return(1);
 }  
 
-/* propogate selection info down into groups */
-void UpdateTraceSelection(Trptr t)
-{
-  if ((t->t_match) && (IsGroupBegin(t) || IsGroupEnd(t)) && (IsSelected(t) || IsSelected(t->t_match)))
-    {
-      t->flags          |= TR_HIGHLIGHT;
-      t->t_match->flags |= TR_HIGHLIGHT;
-    }
-  if ((t->t_grp) && IsSelected(t->t_grp))
-    {
-      t->flags |= TR_HIGHLIGHT;
-    }
-}
 
 Trptr GiveNextTrace(Trptr t)
 {
+  if(!t) return(t); /* should not happen */
+
   /* if(t->name) { printf("NEXT: %s %x\n", t->name, t->flags); } */
   UpdateTraceSelection(t);
   if (IsGroupBegin(t) && IsClosed(t))
@@ -1249,10 +1271,12 @@ Trptr GiveNextTrace(Trptr t)
     }
 }
 
-Trptr GivePrevTrace(Trptr t)
+static Trptr GivePrevTraceSkipUpdate(Trptr t, int skip)
 {
+  if(!t) return(t); /* should not happen */
+
   /* if(t->name) { printf("PREV: %s\n", t->name); } */
-  UpdateTraceSelection(t);
+  if(!skip) { UpdateTraceSelection(t); }
   if (IsGroupEnd(t) && IsClosed(t))
     {
       Trptr prev = t->t_match;
@@ -1269,6 +1293,66 @@ Trptr GivePrevTrace(Trptr t)
     }
 }
 
+Trptr GivePrevTrace(Trptr t)
+{
+return(GivePrevTraceSkipUpdate(t, 0));
+}
+
+
+/* propogate selection info down into groups */
+void UpdateTraceSelection(Trptr t)
+{
+  if ((t->t_match) && (IsGroupBegin(t) || IsGroupEnd(t)) && (IsSelected(t) || IsSelected(t->t_match)))
+    {
+      t->flags          |= TR_HIGHLIGHT;
+      t->t_match->flags |= TR_HIGHLIGHT;
+    }
+  else
+  if ((t->t_grp) && IsSelected(t->t_grp))
+    {
+      t->flags |= TR_HIGHLIGHT;
+    }
+  else
+  if(t->flags & (TR_BLANK|TR_ANALOG_BLANK_STRETCH))  /* seek to real xact trace if present... */
+        {
+	if(!(t->flags & TR_HIGHLIGHT))
+		{
+	        Trptr tscan = t;
+	        int bcnt = 0;
+	        while((tscan) && (tscan = GivePrevTraceSkipUpdate(tscan, 1)))
+	                {
+	                if(!(tscan->flags & (TR_BLANK|TR_ANALOG_BLANK_STRETCH)))
+	                        {
+	                        if(tscan->flags & TR_TTRANSLATED)
+	                                {
+	                                break; /* found it */
+	                                }
+	                                else
+	                                {
+	                                tscan = NULL;
+	                                }
+	                        }
+	                        else
+	                        {
+	                        bcnt++; /* bcnt is number of blank traces */
+	                        }        
+	                }
+	         
+	        if((tscan)&&(tscan->vector)&&(IsSelected(tscan)))
+	                {
+	                bvptr bv = tscan->n.vec;
+	                do
+	                        {
+	                        bv = bv->transaction_chain; /* correlate to blank trace */
+	                        } while(bv && (bcnt--));
+	                if(bv)
+	                        {
+				t->flags |= TR_HIGHLIGHT;
+	                        }
+	                }
+		}
+        }
+}
 
 
 int UpdateTracesVisible(void)
@@ -1333,7 +1417,7 @@ char* GetFullName( Trptr t )
     }
   else if (t->vector)
     {
-      return (t->n.vec->name);
+      return (t->n.vec->bvname);
       
     }
   else
@@ -1409,8 +1493,32 @@ if((underflow_sticky) || (oc_cnt > 0))
 }
 
 /*
- * $Id: analyzer.c,v 1.18 2010/03/14 07:09:49 gtkwave Exp $
+ * $Id: analyzer.c,v 1.26 2010/04/15 00:30:23 gtkwave Exp $
  * $Log: analyzer.c,v $
+ * Revision 1.26  2010/04/15 00:30:23  gtkwave
+ * don't propagate ttranslate filter into groups
+ *
+ * Revision 1.25  2010/04/13 18:11:42  gtkwave
+ * propagate trace highlighting into transactions
+ *
+ * Revision 1.24  2010/04/07 01:50:45  gtkwave
+ * improved name handling for bvname, add $next transaction operation
+ *
+ * Revision 1.23  2010/04/06 06:19:06  gtkwave
+ * deallocate transaction trace name
+ *
+ * Revision 1.22  2010/04/04 19:09:57  gtkwave
+ * rename name->bvname in struct BitVector for easier grep tracking
+ *
+ * Revision 1.21  2010/04/04 07:12:40  gtkwave
+ * deallocate transaction cache on FreeTrace
+ *
+ * Revision 1.20  2010/03/31 16:32:20  gtkwave
+ * stale marker fix for ttranslate on save file loads before GUI initialized
+ *
+ * Revision 1.19  2010/03/31 15:42:47  gtkwave
+ * added preliminary transaction filter support
+ *
  * Revision 1.18  2010/03/14 07:09:49  gtkwave
  * removed ExtNode and merged with Node
  *
