@@ -21,6 +21,7 @@
 #include "debug.h"
 #include "translate.h"
 #include "ptranslate.h"
+#include "ttranslate.h"
 #include "pipeio.h"
 
 #ifdef _MSC_VER
@@ -636,19 +637,50 @@ return(os);
 /*
  * convert trptr+hptr vectorstring into an ascii string
  */
-char *convert_ascii_real(double *d)
+char *convert_ascii_real(Trptr t, double *d)
 {
 char *rv;
 
-rv=malloc_2(24);	/* enough for .16e format */
+if(t && (t->flags & TR_REAL2BITS) && d) /* "real2bits" also allows other filters such as "bits2real" on top of it */
+        {
+	struct TraceEnt t2;
+	char vec[64];
+	int i;
+	guint64 swapmem;
 
-if(d)
+	memcpy(&swapmem, d, sizeof(guint64));
+	for(i=0;i<64;i++)
+		{
+		if(swapmem & (ULLDescriptor(1)<<(63-i)))
+			{
+			vec[i] = AN_1;
+			}
+			else
+			{
+			vec[i] = AN_0;
+			}
+		}
+
+	memcpy(&t2, t, sizeof(struct TraceEnt));
+
+	t2.n.nd->msi = 63;
+	t2.n.nd->lsi = 0;
+	t2.flags &= ~(TR_REAL2BITS); /* to avoid possible recursion in the future */
+
+	rv = convert_ascii_vec_2(&t2, vec);
+        }
+	else
 	{
-	sprintf(rv,"%.16g",*d);	
-	}
-else
-	{
-	strcpy(rv,"UNDEF");
+	rv=malloc_2(24);	/* enough for .16e format */
+
+	if(d)
+		{
+		sprintf(rv,"%.16g",*d);	
+		}
+	else
+		{
+		strcpy(rv,"UNDEF");
+		}
 	}
 
 return(rv);
@@ -702,8 +734,16 @@ int vtype2(Trptr t, vptr v)
 	int i, nbits, res;
 	char *vec=(char *)v->v;
 
-	if (vec == NULL)
-		return(1);
+	if(!t->t_filter_converted)
+		{
+		if (vec == NULL)
+			return(AN_X);
+		}
+		else
+		{
+		return ( ((vec == NULL) || (vec[0] == 0)) ? AN_Z : AN_0 );
+		}
+
 	nbits=t->n.vec->nbits;
 	res = AN_1;
 	for (i = 0; i < nbits; i++)
@@ -728,7 +768,7 @@ int vtype2(Trptr t, vptr v)
 /*
  * convert trptr+hptr vectorstring into an ascii string
  */
-static char *convert_ascii_vec_2(Trptr t, char *vec)
+char *convert_ascii_vec_2(Trptr t, char *vec)
 {
 Ulong flags;
 int nbits;
@@ -1349,7 +1389,30 @@ return(s);
 
 char *convert_ascii(Trptr t, vptr v)
 {
-char *s = convert_ascii_2(t, v);
+char *s;
+
+if(!t->t_filter_converted)
+	{
+	s = convert_ascii_2(t, v);
+	}
+	else
+	{
+	s = strdup_2(v->v);
+
+	if((*s == '?') && (!GLOBALS->color_active_in_filter))
+	        {  
+	        char *s2a;
+	        char *s2 = strchr(s+1, '?');
+	        if(s2)
+	                {
+	                s2++;
+	                s2a = malloc_2(strlen(s2)+1);
+	                strcpy(s2a, s2);
+	                free_2(s);
+	                s = s2a;
+	                }   
+	        }
+	}
 
 #if defined _MSC_VER || defined __MINGW32__
 
@@ -1655,8 +1718,17 @@ return(retval);
 }
 
 /*
- * $Id: baseconvert.c,v 1.13 2010/03/14 07:09:49 gtkwave Exp $
+ * $Id: baseconvert.c,v 1.16 2010/03/31 16:32:20 gtkwave Exp $
  * $Log: baseconvert.c,v $
+ * Revision 1.16  2010/03/31 16:32:20  gtkwave
+ * stale marker fix for ttranslate on save file loads before GUI initialized
+ *
+ * Revision 1.15  2010/03/31 15:42:47  gtkwave
+ * added preliminary transaction filter support
+ *
+ * Revision 1.14  2010/03/24 23:05:09  gtkwave
+ * added RealToBits menu option
+ *
  * Revision 1.13  2010/03/14 07:09:49  gtkwave
  * removed ExtNode and merged with Node
  *
