@@ -20,7 +20,7 @@
 #include "regex_wave.h"
 #include "translate.h"
 
-#define WAVE_VERSION_INFO "GTKWave Analyzer v3.3.5 (w)1999-2010 BSI"
+#define WAVE_VERSION_INFO "GTKWave Analyzer v3.3.7 (w)1999-2010 BSI"
 
 #define WAVE_INF_SCALING (0.5)
 #define WAVE_SI_UNITS " munpfaz"
@@ -45,8 +45,9 @@ TimeType bstart, bend;
 void fractional_timescale_fix(char *);
 char *convert_ascii(Trptr t, vptr v);
 char *convert_ascii_vec(Trptr t, char *vec);
-char *convert_ascii_real(double *d);
+char *convert_ascii_real(Trptr t, double *d);
 char *convert_ascii_string(char *s);
+char *convert_ascii_vec_2(Trptr t, char *vec);
 double convert_real_vec(Trptr t, char *vec);
 double convert_real(Trptr t, vptr v);
 
@@ -65,6 +66,7 @@ void UpdateSigValue(Trptr t);
 void MaxSignalLength(void);
 void RenderSigs(int trtarget, int update_waves);
 int RenderSig(Trptr t, int i, int dobackground);
+void populateBuffer(Trptr t, char *altname, char* buf);
 void calczoom(double z0);
 void fix_wavehadj(void);
 void service_zoom_in(GtkWidget *text, gpointer data);
@@ -174,8 +176,23 @@ void do_popup_menu (GtkWidget *my_widget, GdkEventButton *event);
 #endif
 
 /*
- * $Id: currenttime.h,v 1.72 2010/03/19 16:36:47 gtkwave Exp $
+ * $Id: currenttime.h,v 1.77 2010/06/04 20:26:12 gtkwave Exp $
  * $Log: currenttime.h,v $
+ * Revision 1.77  2010/06/04 20:26:12  gtkwave
+ * version bump
+ *
+ * Revision 1.76  2010/05/06 15:57:52  gtkwave
+ * enable_fast_exit now is enabled by default
+ *
+ * Revision 1.75  2010/05/03 21:42:16  gtkwave
+ * version bump
+ *
+ * Revision 1.74  2010/04/14 04:21:46  gtkwave
+ * update populateBuffer() usage
+ *
+ * Revision 1.73  2010/03/24 23:05:09  gtkwave
+ * added RealToBits menu option
+ *
  * Revision 1.72  2010/03/19 16:36:47  gtkwave
  * version bump
  *
