@@ -67,7 +67,10 @@ struct strace s_tmp;
 struct strace *s_head, *s;
 TimeType basetime, maxbase, sttim, fintim;
 Trptr t = find_first_highlighted_trace();
-int totaltraces, passcount;
+int totaltraces;
+#ifdef DEBUG_PRINTF
+int passcount;
+#endif
 int whichpass;
 TimeType middle=0, width;
 
@@ -133,7 +136,7 @@ while(s)
 		UTimeType utt;
 		TimeType  tt;
 
-		h=bsearch_node(t->n.nd, basetime);
+		h=bsearch_node(t->n.nd, basetime - t->shift);
 		hp=GLOBALS->max_compare_index;
 		if((hp==&(t->n.nd->harray[1]))||(hp==&(t->n.nd->harray[0]))) return;
 		if(basetime == ((*hp)->time+GLOBALS->shift_timebase)) hp--;
@@ -149,7 +152,7 @@ while(s)
 		UTimeType utt;
 		TimeType  tt;
 
-		v=bsearch_vector(t->n.vec, basetime);
+		v=bsearch_vector(t->n.vec, basetime - t->shift);
 		vp=GLOBALS->vmax_compare_index;
 		if((vp==&(t->n.vec->vectors[1]))||(vp==&(t->n.vec->vectors[0]))) return;
 		if(basetime == ((*vp)->time+GLOBALS->shift_timebase)) vp--;
@@ -176,7 +179,7 @@ while(s)
 		UTimeType utt;
 		TimeType  tt;
 
-		h=bsearch_node(t->n.nd, basetime);
+		h=bsearch_node(t->n.nd, basetime - t->shift);
 		while(h->next && h->time==h->next->time) h=h->next;
 		if((whichpass)||(GLOBALS->tims.marker>=0)) h=h->next;
 		if(!h) return;
@@ -190,7 +193,7 @@ while(s)
 		UTimeType utt;
 		TimeType  tt;
 
-		v=bsearch_vector(t->n.vec, basetime);
+		v=bsearch_vector(t->n.vec, basetime - t->shift);
 		while(v->next && v->time==v->next->time) v=v->next;
 		if((whichpass)||(GLOBALS->tims.marker>=0)) v=v->next;
 		if(!v) return;
@@ -216,7 +219,7 @@ while(s)
 		{
 		if(strace_adjust(s->his.h->time,GLOBALS->shift_timebase)!=maxbase) 
 			{
-			s->his.h=bsearch_node(t->n.nd, maxbase);
+			s->his.h=bsearch_node(t->n.nd, maxbase - t->shift);
 			while(s->his.h->next && s->his.h->time==s->his.h->next->time) s->his.h=s->his.h->next;
 			}
 		if(t->flags&TR_INVERT)  
@@ -296,7 +299,7 @@ while(s)
 			{
 			if(strace_adjust(s->his.v->time,GLOBALS->shift_timebase)!=maxbase) 
 				{
-				s->his.v=bsearch_vector(t->n.vec, maxbase);
+				s->his.v=bsearch_vector(t->n.vec, maxbase - t->shift);
 				while(s->his.v->next && s->his.v->time==s->his.v->next->time) s->his.v=s->his.v->next;
 				}
 			chval=convert_ascii(t,s->his.v);
@@ -305,14 +308,14 @@ while(s)
 			{
 			if(strace_adjust(s->his.h->time,GLOBALS->shift_timebase)!=maxbase) 
 				{
-				s->his.h=bsearch_node(t->n.nd, maxbase);
+				s->his.h=bsearch_node(t->n.nd, maxbase - t->shift);
 				while(s->his.h->next && s->his.h->time==s->his.h->next->time) s->his.h=s->his.h->next;
 				}
 			if(s->his.h->flags&HIST_REAL)
 				{
 				if(!(s->his.h->flags&HIST_STRING))
 					{
-					chval=convert_ascii_real((double *)s->his.h->v.h_vector);
+					chval=convert_ascii_real(t, (double *)s->his.h->v.h_vector);
 					}
 					else
 					{
@@ -429,6 +432,7 @@ while(s)
 
 if((maxbase<sttim)||(maxbase>fintim)) return;
 
+#ifdef DEBUG_PRINTF
 DEBUG(printf("Maxbase: "TTFormat", total traces: %d\n",maxbase, totaltraces));
 s=s_head;
 passcount=0;
@@ -438,6 +442,7 @@ while(s)
 	if(s->search_result) passcount++;
 	s=s->next;
 	}
+#endif
 
 if(totaltraces)
 	{
@@ -573,8 +578,17 @@ return(table);
 }
    
 /*
- * $Id: edgebuttons.c,v 1.8 2010/03/14 07:09:49 gtkwave Exp $
+ * $Id: edgebuttons.c,v 1.11 2010/05/01 19:46:28 gtkwave Exp $
  * $Log: edgebuttons.c,v $
+ * Revision 1.11  2010/05/01 19:46:28  gtkwave
+ * cppcheck warning fixes
+ *
+ * Revision 1.10  2010/04/01 03:10:58  gtkwave
+ * time warp fixes
+ *
+ * Revision 1.9  2010/03/24 23:05:09  gtkwave
+ * added RealToBits menu option
+ *
  * Revision 1.8  2010/03/14 07:09:49  gtkwave
  * removed ExtNode and merged with Node
  *
