@@ -29,6 +29,7 @@
 #include "pixmaps.h"
 #include "print.h"
 #include "ptranslate.h"
+#include "ttranslate.h"
 #include "rc.h"
 #include "regex_wave.h"
 #include "strace.h"
@@ -838,6 +839,12 @@ NULL, /* curnode 431 */
 0, /* hashcache 432 */
 
 
+/*
+ * tcl_commands.c
+ */
+NULL, /* previous_braced_tcl_string */
+
+
 /*
  * timeentry.c
  */
@@ -928,6 +935,21 @@ NULL, /* cleanup_treesearch_gtk2_c_8 468 */
 0, /* dnd_tgt_on_wavearea_treesearch_gtk2_c_1 */
 NULL, /* dnd_sigview */
 
+
+/*
+ * ttranslate.c
+ */
+0, /* current_translate_ttrans */
+0, /* current_filter_ttranslate_c_1 */
+0, /* num_ttrans_filters */
+NULL, /* ttranssel_filter */
+NULL, /* ttrans_filter */
+0, /* is_active_ttranslate_c_2 */
+NULL, /* fcurr_ttranslate_c_1 */
+NULL, /* window_ttranslate_c_5 */
+NULL, /* clist_ttranslate_c_2 */
+
+
 /*
  * vcd.c
  */
@@ -1108,7 +1130,8 @@ NULL, /* mvlfacs_vzt_c_3 587 */
  */
 0, /* use_scrollwheel_as_y */
 0, /* m1x_wavewindow_c_1 589 */
-0, /* m2x */
+0, /* m2x_wavewindow_c_1 */
+0, /* black_and_white */
 1, /* signalwindow_width_dirty 590 */
 1, /* enable_ghost_marker 591 */
 1, /* enable_horiz_grid 592 */
@@ -1379,6 +1402,7 @@ void reload_into_new_context(void)
 
  /* Kill any open processes */
  remove_all_proc_filters();
+ remove_all_ttrans_filters();
 
  /* Instantiate new global status */
  new_globals = initialize_globals();
@@ -1434,6 +1458,8 @@ void reload_into_new_context(void)
  new_globals->wave_splash_pixmap = GLOBALS->wave_splash_pixmap;
  new_globals->wave_splash_mask = GLOBALS->wave_splash_mask;
 
+ new_globals->black_and_white = GLOBALS->black_and_white;
+
  new_globals->gc_white = GLOBALS->gc_white;
  new_globals->gc_black = GLOBALS->gc_black;
  new_globals->gc_ltgray = GLOBALS->gc_ltgray;
@@ -1483,6 +1509,7 @@ void reload_into_new_context(void)
  new_globals->gccache_gmstrd = GLOBALS->gccache_gmstrd;
  new_globals->gccache_back_wavewindow_c_1 = GLOBALS->gccache_back_wavewindow_c_1;
  new_globals->gccache_baseline_wavewindow_c_1 = GLOBALS->gccache_baseline_wavewindow_c_1;
+ new_globals->gccache_grid_wavewindow_c_1 = GLOBALS->gccache_grid_wavewindow_c_1;
  new_globals->gccache_grid2_wavewindow_c_1 = GLOBALS->gccache_grid2_wavewindow_c_1;
  new_globals->gccache_time_wavewindow_c_1 = GLOBALS->gccache_time_wavewindow_c_1;
  new_globals->gccache_timeb_wavewindow_c_1 = GLOBALS->gccache_timeb_wavewindow_c_1;
@@ -1716,6 +1743,7 @@ void reload_into_new_context(void)
  strcpy2_into_new_context(new_globals, &new_globals->stems_name, &GLOBALS->stems_name); /* remaining fileselbox() vars not handled elsewhere */
  strcpy2_into_new_context(new_globals, &new_globals->filesel_logfile_menu_c_1, &GLOBALS->filesel_logfile_menu_c_1);
  strcpy2_into_new_context(new_globals, &new_globals->filesel_scriptfile_menu, &GLOBALS->filesel_scriptfile_menu);
+ strcpy2_into_new_context(new_globals, &new_globals->fcurr_ttranslate_c_1, &GLOBALS->fcurr_ttranslate_c_1);
  strcpy2_into_new_context(new_globals, &new_globals->fcurr_ptranslate_c_1, &GLOBALS->fcurr_ptranslate_c_1);
  strcpy2_into_new_context(new_globals, &new_globals->fcurr_translate_c_2, &GLOBALS->fcurr_translate_c_2);
  
@@ -1928,6 +1956,7 @@ void reload_into_new_context(void)
 
  init_filetrans_data();
  init_proctrans_data();
+ init_ttrans_data();
  /* load_all_fonts(); */
 
  /* attempt to reload file and recover on loader errors until successful */
@@ -2007,7 +2036,6 @@ void reload_into_new_context(void)
 				Index = 0;
 				for (rcValue = Judy1First(PJArray, &Index, &JError); rcValue != 0; rcValue = Judy1Next(PJArray, &Index, &JError))
 					{
-				        JError_t JError;
 				        Judy1Set ((Pvoid_t)&GLOBALS->alloc2_chain, Index, &JError);
 					}
 
