@@ -42,6 +42,7 @@
 #include "pixmaps.h"
 #include "print.h"
 #include "ptranslate.h"
+#include "ttranslate.h"
 #include "rc.h"
 #include "regex_wave.h"
 #include "strace.h"
@@ -821,6 +822,12 @@ struct symchain *curnode; /* from symbol.c 460 */
 int hashcache; /* from symbol.c 461 */
 
 
+/*
+ * tcl_commands.c
+ */
+char *previous_braced_tcl_string;
+
+
 /*
  * timeentry.c
  */
@@ -911,6 +918,21 @@ unsigned char dnd_tgt_on_signalarea_treesearch_gtk2_c_1; /* from treesearch_gtk2
 unsigned char dnd_tgt_on_wavearea_treesearch_gtk2_c_1; /* from treesearch_gtk2.c */
 GtkWidget *dnd_sigview; /* from treesearch_gtk2.c */
 
+
+/*
+ * ttranslate.c
+ */
+int current_translate_ttrans;
+int current_filter_ttranslate_c_1;
+int num_ttrans_filters;
+char **ttranssel_filter;
+struct pipe_ctx **ttrans_filter;
+int is_active_ttranslate_c_2;
+char *fcurr_ttranslate_c_1;
+GtkWidget *window_ttranslate_c_5;
+GtkWidget *clist_ttranslate_c_2;
+
+
 /*
  * vcd.c
  */
@@ -1092,6 +1114,7 @@ int busycnt_vzt_c_2; /* from vzt.c 641 */
 char use_scrollwheel_as_y; /* fromwavewindow.c */
 int m1x_wavewindow_c_1; /* from wavewindow.c 642 */
 int m2x_wavewindow_c_1; /* from wavewindow.c 643 */
+char black_and_white; /* from wavewindow.c */
 char signalwindow_width_dirty; /* from wavewindow.c 644 */
 char enable_ghost_marker; /* from wavewindow.c 645 */
 char enable_horiz_grid; /* from wavewindow.c 646 */
