@@ -109,8 +109,13 @@ return(pnt);
 }
 #else
 #include <sys/mman.h>
-#define fstMmap(__addr,__len,__prot,__flags,__fd,__off) mmap((__addr),(__len),(__prot),(__flags),(__fd),(__off))
-#define fstMunmap(__addr,__len) 			munmap((__addr),(__len))
+#if defined(__SUNPRO_C)
+#define FST_CADDR_T_CAST (caddr_t)
+#else
+#define FST_CADDR_T_CAST
+#endif
+#define fstMmap(__addr,__len,__prot,__flags,__fd,__off) (void*)mmap(FST_CADDR_T_CAST (__addr),(__len),(__prot),(__flags),(__fd),(__off))
+#define fstMunmap(__addr,__len) 			{ if(__addr) munmap(FST_CADDR_T_CAST (__addr),(__len)); }
 #endif
 
 
@@ -229,21 +234,26 @@ return(rc);
 }
 
 
-static int fstCopyVarint32(unsigned char *pnt, uint32_t v)
+static unsigned char *fstCopyVarint32ToLeft(unsigned char *pnt, uint32_t v)
 {
-unsigned char *spnt = pnt;
+unsigned char buf[5];
+unsigned char *spnt = buf;  
 uint32_t nxt;
 
 while((nxt = v>>7))
         {
-        *(pnt++) = (v&0x7f) | 0x80;
+        *(spnt++) = (v&0x7f) | 0x80;
         v = nxt;
         }
-*(pnt++) = (v&0x7f);
+*(spnt++) = (v&0x7f);
 
-return(pnt - spnt);
+do      {
+        *(--pnt) = *(--spnt);
+        } while(spnt != buf);
+
+return(pnt);
 }
-
+ 
 
 static uint64_t fstGetVarint64(unsigned char *mem, int *skiplen)
 {
@@ -411,7 +421,6 @@ uint32_t *valpos_mem;
 unsigned char *curval_mem;
 
 char *filename;
-time_t simdate;
 
 fstHandle maxhandle;
 fstHandle numsigs;
@@ -443,6 +452,10 @@ unsigned compress_hier : 1;
 unsigned repack_on_close : 1;
 unsigned skip_writing_section_hdr : 1;
 unsigned size_limit_locked : 1;
+
+/* should really be semaphores, but are bytes to cut down on read-modify-write window size */
+unsigned char already_in_flush; /* in case control-c handlers interrupt */
+unsigned char already_in_close; /* in case control-c handlers interrupt */
 };
 
 
@@ -542,18 +555,34 @@ if(!xc->curval_mem)
 }
 
 
-static void fstDestroyMmaps(struct fstWriterContext *xc)
+static void fstDestroyMmaps(struct fstWriterContext *xc, int is_closing)
 {
-if(xc->valpos_mem)
-	{
-	fstMunmap(xc->valpos_mem, xc->maxhandle * 4 * sizeof(uint32_t));
-	xc->valpos_mem = NULL;
-	}
+fstMunmap(xc->valpos_mem, xc->maxhandle * 4 * sizeof(uint32_t));
+xc->valpos_mem = NULL;
+
+#if defined __CYGWIN__ || defined __MINGW32__
 if(xc->curval_mem)
 	{
-	fstMunmap(xc->curval_mem, xc->maxvalpos);
-	xc->curval_mem = NULL;
+	if(!is_closing) /* need to flush out for next emulated mmap() read */
+		{
+		unsigned char *pnt = xc->curval_mem;
+		int __fd = fileno(xc->curval_handle);
+		off_t cur_offs = lseek(__fd, 0, SEEK_CUR);
+		size_t i;
+		size_t __len = xc->maxvalpos;
+
+		lseek(__fd, 0, SEEK_SET);
+		for(i=0;i<__len;i+=SSIZE_MAX)
+		        {
+		        write(__fd, pnt + i, ((__len - i) >= SSIZE_MAX) ? SSIZE_MAX : (__len - i));
+		        }
+		lseek(__fd, cur_offs, SEEK_SET);
+		}
 	}
+#endif
+
+fstMunmap(xc->curval_mem, xc->maxvalpos);
+xc->curval_mem = NULL;
 }
 
 
@@ -615,11 +644,13 @@ return(xc);
 void fstWriterClose(void *ctx)
 {
 struct fstWriterContext *xc = (struct fstWriterContext *)ctx;
-if(xc)
+if(xc && !xc->already_in_close && !xc->already_in_flush)
 	{
 	unsigned char *tmem;
 	off_t fixup_offs, tlen, hlen;
 
+	xc->already_in_close = 1; /* never need to zero this out as it is freed at bottom */
+
 	xc->skip_writing_section_hdr = 1;
 	if(!xc->size_limit_locked)
 		{
@@ -635,7 +666,7 @@ if(xc)
 			}
 		fstWriterFlushContext(xc);
 		}
-	fstDestroyMmaps(xc);
+	fstDestroyMmaps(xc, 1);
 
 	/* write out geom section */
 	fflush(xc->geom_handle);
@@ -784,7 +815,6 @@ if(xc)
 			if(fp)
 				{
 				void *dsth;
-				int rc;
 				char gz_membuf[FST_GZIO_LEN];
 
 				fseeko(xc->handle, 0, SEEK_END);
@@ -801,7 +831,7 @@ if(xc)
 				for(offpnt = 0; offpnt < uclen; offpnt += FST_GZIO_LEN)
 					{
 					size_t this_len = ((uclen - offpnt) > FST_GZIO_LEN) ? FST_GZIO_LEN : (uclen - offpnt);
-					rc = fstFread(gz_membuf, this_len, 1, xc->handle);
+					fstFread(gz_membuf, this_len, 1, xc->handle);
 					gzwrite(dsth, gz_membuf, this_len);
 					}
 				gzclose(dsth);
@@ -845,8 +875,7 @@ if(xc)
 	}
 #endif
 
-	if(xc->filename) { free(xc->filename); xc->filename = NULL; }
-
+	free(xc->filename); xc->filename = NULL;
 	free(xc);
 	}
 }
@@ -903,7 +932,9 @@ if(xc)
 
 void fstWriterFlushContext(void *ctx)
 {
+#ifdef FST_DEBUG
 int cnt = 0;
+#endif
 int i;
 unsigned char *vchg_mem;
 FILE *f;
@@ -915,10 +946,14 @@ unsigned char *scratchpnt;
 unsigned char *tmem;
 off_t tlen;
 off_t unc_memreq = 0; /* for reader */
+unsigned char *packmem;
+unsigned int packmemlen;
+uint32_t *vm4ip;
 
 struct fstWriterContext *xc = (struct fstWriterContext *)ctx;
 
-if((!xc)||(xc->vchn_siz <= 1)) return;
+if((!xc)||(xc->vchn_siz <= 1)||(xc->already_in_flush)) return;
+xc->already_in_flush = 1; /* should really do this with a semaphore */
 
 scratchpad = malloc(xc->vchn_siz);
 
@@ -930,28 +965,23 @@ fstWriterVarint(f, xc->maxhandle);	/* emit current number of handles */
 fputc(xc->fastpack ? 'F' : 'Z', f);
 fpos = 1;
 
+packmemlen = 1024;			/* maintain a running "longest" allocation to */
+packmem = malloc(packmemlen);		/* prevent continual malloc...free every loop iter */
+
 for(i=0;i<xc->maxhandle;i++)
 	{
-	if(xc->valpos_mem[4*i+2]) 
+	vm4ip = &(xc->valpos_mem[4*i]);
+
+	if(vm4ip[2]) 
 		{
-		uint32_t offs = xc->valpos_mem[4*i+2];
-		uint32_t next_offs = 0;
+		uint32_t offs = vm4ip[2];
+		uint32_t next_offs;
 		int wrlen;
-		uint32_t offs2;
 
-		while(offs)	/* go backwards and relink forwards */
-			{
-			offs2 = fstGetUint32(vchg_mem + offs);
-			fstWriterSetUint32(vchg_mem + offs, next_offs);
-			next_offs = offs;
-			offs = offs2;
-			}
+		vm4ip[2] = fpos;
 
-		xc->valpos_mem[4*i+2] = fpos;
-
-		offs = next_offs;
-		scratchpnt = scratchpad;
-		if(xc->valpos_mem[4*i+1] == 1)
+		scratchpnt = scratchpad + xc->vchn_siz;		/* build this buffer backwards */
+		if(vm4ip[1] == 1)
 			{
                         while(offs)
                                 {
@@ -962,6 +992,7 @@ for(i=0;i<xc->maxhandle;i++)
                         
                                 time_delta = fstGetVarint32(vchg_mem + offs, &wrlen);
                                 val = vchg_mem[offs+wrlen];
+				offs = next_offs;
 
                                 switch(val)
                                         {
@@ -978,8 +1009,7 @@ for(i=0;i<xc->maxhandle;i++)
                                         default:                rcv = FST_RCV_D | (time_delta<<4); break;
                                         }
                 
-                                scratchpnt += fstCopyVarint32(scratchpnt, rcv);
-				offs = next_offs;
+                                scratchpnt = fstCopyVarint32ToLeft(scratchpnt, rcv);
 				}
 			}
 			else
@@ -997,7 +1027,9 @@ for(i=0;i<xc->maxhandle;i++)
 				time_delta = fstGetVarint32(vchg_mem + offs, &wrlen);
 
 				pnt = vchg_mem+offs+wrlen;
-				for(idx=0;idx<xc->valpos_mem[4*i+1];idx++)
+				offs = next_offs;
+
+				for(idx=0;idx<vm4ip[1];idx++)
 					{
 					if((pnt[idx] == '0') || (pnt[idx] == '1'))
 						{
@@ -1013,36 +1045,32 @@ for(i=0;i<xc->maxhandle;i++)
 				if(is_binary)
 					{
 					unsigned char acc = 0;
-					int shift = 7;
-	                                scratchpnt += fstCopyVarint32(scratchpnt, (time_delta << 1));
-					for(idx=0;idx<xc->valpos_mem[4*i+1];idx++)
+					int shift = 7 - ((vm4ip[1]-1) & 7);
+					for(idx=vm4ip[1]-1;idx>=0;idx--)
 						{
 						acc |= (pnt[idx] & 1) << shift;
-						shift--;
-						if(shift < 0)
+						shift++;
+						if(shift == 8)
 							{
-							*(scratchpnt++) = acc;
-							shift = 7;
+							*(--scratchpnt) = acc;
+							shift = 0;
 							acc = 0;
 							}						
 						}					
-					if(shift != 7)
-						{
-						*(scratchpnt++) = acc;
-						}
+
+	                                scratchpnt = fstCopyVarint32ToLeft(scratchpnt, (time_delta << 1));
 					}
 					else
 					{
-	                                scratchpnt += fstCopyVarint32(scratchpnt, (time_delta << 1) | 1);
-					memcpy(scratchpnt, pnt, xc->valpos_mem[4*i+1]);
-					scratchpnt += xc->valpos_mem[4*i+1];
-					}
+					scratchpnt -= vm4ip[1];
+					memcpy(scratchpnt, pnt, vm4ip[1]);
 
-				offs = next_offs;
+	                                scratchpnt = fstCopyVarint32ToLeft(scratchpnt, (time_delta << 1) | 1);
+					}
 				}
 			}
 
-		wrlen = scratchpnt - scratchpad;
+		wrlen = scratchpad + xc->vchn_siz - scratchpnt;
 		unc_memreq += wrlen;
 		if(wrlen > 32)
 			{
@@ -1052,8 +1080,17 @@ for(i=0;i<xc->maxhandle;i++)
 
 			if(!xc->fastpack)
 				{
-				dmem = malloc(wrlen);
-		        	rc = compress2(dmem, &destlen, scratchpad, wrlen, 4);
+				if(wrlen <= packmemlen)
+					{
+					dmem = packmem;
+					}
+					else
+					{
+					free(packmem);
+					dmem = packmem = malloc(packmemlen = wrlen);
+					}
+
+		        	rc = compress2(dmem, &destlen, scratchpnt, wrlen, 4);
 				if(rc == Z_OK)
 					{
 					fpos += fstWriterVarint(f, wrlen);
@@ -1064,14 +1101,22 @@ for(i=0;i<xc->maxhandle;i++)
 					{
 					fpos += fstWriterVarint(f, 0);
 					fpos += wrlen;
-					fstFwrite(scratchpad, wrlen, 1, f);
+					fstFwrite(scratchpnt, wrlen, 1, f);
 					}
-				free(dmem);
 				}
 				else
 				{
-				dmem = malloc((wrlen * 2) + 2);
-				rc = fastlz_compress(scratchpad, wrlen, dmem);
+				if(((wrlen * 2) + 2) <= packmemlen)
+					{
+					dmem = packmem;
+					}
+					else
+					{
+					free(packmem);
+					dmem = packmem = malloc(packmemlen = (wrlen * 2) + 2);
+					}
+
+				rc = fastlz_compress(scratchpnt, wrlen, dmem);
 				if(rc < destlen)
         				{
 					fpos += fstWriterVarint(f, wrlen);
@@ -1082,23 +1127,26 @@ for(i=0;i<xc->maxhandle;i++)
         				{
 					fpos += fstWriterVarint(f, 0);
 					fpos += wrlen;
-					fstFwrite(scratchpad, wrlen, 1, f);
+					fstFwrite(scratchpnt, wrlen, 1, f);
         				}
-				free(dmem);
 				}
 			}
 			else
 			{
 			fpos += fstWriterVarint(f, 0);
 			fpos += wrlen;
-			fstFwrite(scratchpad, wrlen, 1, f);
+			fstFwrite(scratchpnt, wrlen, 1, f);
 			}
 
-		xc->valpos_mem[4*i+3] = 0;
+		vm4ip[3] = 0;
+#ifdef FST_DEBUG
 		cnt++;
+#endif
 		}
 	}
 
+free(packmem); packmem = NULL; packmemlen = 0;
+
 prevpos = 0; zerocnt = 0;
 free(scratchpad); scratchpad = NULL;
 
@@ -1107,7 +1155,9 @@ xc->secnum++;
 
 for(i=0;i<xc->maxhandle;i++)
 	{
-	if(xc->valpos_mem[4*i+2])
+	vm4ip = &(xc->valpos_mem[4*i]);
+
+	if(vm4ip[2])
 		{
 		if(zerocnt)
 			{
@@ -1115,10 +1165,10 @@ for(i=0;i<xc->maxhandle;i++)
 			zerocnt = 0;
 			}
 
-		fpos += fstWriterVarint(f, ((xc->valpos_mem[4*i+2] - prevpos) << 1) | 1);
-		prevpos = xc->valpos_mem[4*i+2];
-		xc->valpos_mem[4*i+2] = 0;
-		xc->valpos_mem[4*i+3] = 0; /* clear out tchn idx */
+		fpos += fstWriterVarint(f, ((vm4ip[2] - prevpos) << 1) | 1);
+		prevpos = vm4ip[2];
+		vm4ip[2] = 0;
+		vm4ip[3] = 0; /* clear out tchn idx */
 		}
 		else
 		{
@@ -1210,6 +1260,8 @@ if(!xc->skip_writing_section_hdr)
 	fstWriterEmitSectionHeader(xc);				/* emit next section header */
 	}
 fflush(xc->handle);
+
+xc->already_in_flush = 0;
 }
 
 
@@ -1268,6 +1320,50 @@ if(xc)
 }
 
 
+void fstWriterSetTimescaleFromString(void *ctx, const char *s)
+{
+struct fstWriterContext *xc = (struct fstWriterContext *)ctx;
+if(xc && s)
+        {
+        int mat = 0;
+	int seconds_exp = -9;
+	int tv = atoi(s);
+	const char *pnt = s;
+
+	while(*pnt)
+        	{
+                switch(*pnt)
+                	{
+                        case 'm': seconds_exp = -3; mat = 1; break;
+                        case 'u': seconds_exp = -6; mat = 1; break;
+                        case 'n': seconds_exp = -9; mat = 1; break;
+                        case 'p': seconds_exp = -12; mat = 1; break;
+                        case 'f': seconds_exp = -15; mat = 1; break;
+                        case 'a': seconds_exp = -18; mat = 1; break;
+                        case 'z': seconds_exp = -21; mat = 1; break;
+                        case 's': seconds_exp = -0; mat = 1; break;
+                        default: break;
+                        }
+
+		if(mat) break;
+                pnt++;
+                }
+
+	if(tv == 10)
+        	{
+                seconds_exp++;
+                } 
+        else
+        if(tv == 100)
+        	{
+                seconds_exp+=2;
+                }
+                              
+	fstWriterSetTimescale(ctx, seconds_exp);
+        }
+}
+
+
 void fstWriterSetPackType(void *ctx, int typ)
 {
 struct fstWriterContext *xc = (struct fstWriterContext *)ctx;
@@ -1298,6 +1394,18 @@ if(xc)
 }
 
 
+int fstWriterGetDumpSizeLimitReached(void *ctx)
+{
+struct fstWriterContext *xc = (struct fstWriterContext *)ctx;
+if(xc)
+        {
+        return(xc->size_limit_locked != 0);
+        }
+
+return(0);
+}
+
+
 /*
  * writer scope/var creation
  */
@@ -1311,7 +1419,7 @@ if(xc && nam)
         {
 	if(xc->valpos_mem)
 		{
-		fstDestroyMmaps(xc);
+		fstDestroyMmaps(xc, 0);
 		}
 
 	fputc(vt, xc->hier_handle);
@@ -1428,31 +1536,32 @@ if((xc) && (handle <= xc->maxhandle))
 	{
 	uint32_t prev_chg;
 	uint32_t fpos;
+	uint32_t *vm4ip;
 
 	if(!xc->valpos_mem)
 		{
+		xc->vc_emitted = 1;
 		fstWriterCreateMmaps(xc);
 		}
 
-	xc->vc_emitted = 1;
-
 	handle--; /* move starting at 1 index to starting at 0 */
-	offs = xc->valpos_mem[4*handle];
-	len  = xc->valpos_mem[4*handle+1];
+	vm4ip = &(xc->valpos_mem[4*handle]);
+	offs = vm4ip[0];
+	len  = vm4ip[1];
 	memcpy(xc->curval_mem + offs, buf, len);
 
 	if(!xc->is_initial_time)
 		{
-		prev_chg = xc->valpos_mem[4*handle+2];
+		prev_chg = vm4ip[2];
 		fpos = xc->vchn_siz;
 
 		fstFwrite(&prev_chg, 1, sizeof(uint32_t), xc->vchn_handle);
 		xc->vchn_siz += 4;
-		xc->valpos_mem[4*handle+2] = fpos;
-		xc->vchn_siz += fstWriterVarint(xc->vchn_handle, xc->tchn_idx - xc->valpos_mem[4*handle+3]);
-		xc->valpos_mem[4*handle+3] = xc->tchn_idx;
+		xc->vchn_siz += fstWriterVarint(xc->vchn_handle, xc->tchn_idx - vm4ip[3]);
 		fstFwrite(buf, len, 1, xc->vchn_handle);
 		xc->vchn_siz += len;
+		vm4ip[3] = xc->tchn_idx;
+		vm4ip[2] = fpos;
 		}
 	}
 }
@@ -1653,7 +1762,7 @@ static void fstReaderDeallocateScopeData(struct fstReaderContext *xc)
 {
 struct fstCurrHier *chp;
 
-if(xc->curr_flat_hier_nam) { free(xc->curr_flat_hier_nam); xc->curr_flat_hier_nam = NULL; }
+free(xc->curr_flat_hier_nam); xc->curr_flat_hier_nam = NULL;
 while(xc->curr_hier)
 	{
 	chp = xc->curr_hier->prev;
@@ -2228,7 +2337,7 @@ struct fstReaderContext *xc = (struct fstReaderContext *)ctx;
 char str[FST_ID_NAM_SIZ+1];
 char *pnt;
 int ch, scopetype;
-int vartype, vardir;
+int vartype;
 uint32_t len, alias;
 uint32_t maxvalpos=0;
 int num_signal_dyn = 65536;
@@ -2290,10 +2399,10 @@ if(fv)
 xc->maxhandle = 0;
 xc->num_alias = 0;
 
-if(xc->signal_lens) free(xc->signal_lens);
+free(xc->signal_lens);
 xc->signal_lens = malloc(num_signal_dyn*sizeof(uint32_t));
 
-if(xc->signal_typs) free(xc->signal_typs);
+free(xc->signal_typs);
 xc->signal_typs = malloc(num_signal_dyn*sizeof(unsigned char));
 
 fseeko(xc->fh, 0, SEEK_SET);
@@ -2341,7 +2450,7 @@ while(!feof(xc->fh))
 		case FST_VT_VCD_ARRAY:
 		case FST_VT_VCD_REALTIME:
 			vartype = tag;
-			vardir = fgetc(xc->fh);
+			/* vardir = */ fgetc(xc->fh); /* unused in VCD reader, but need to advance read pointer */
 			pnt = str;
 			while((ch = fgetc(xc->fh))) 
 				{
@@ -2406,10 +2515,10 @@ if(fv) fprintf(fv, "$enddefinitions $end\n");
 xc->signal_lens = realloc(xc->signal_lens, xc->maxhandle*sizeof(uint32_t));
 xc->signal_typs = realloc(xc->signal_typs, xc->maxhandle*sizeof(unsigned char));
 
-if(xc->process_mask) { free(xc->process_mask); }
+free(xc->process_mask);
 xc->process_mask = calloc(1, (xc->maxhandle+7)/8);
 
-if(xc->temp_signal_value_buf) free(xc->temp_signal_value_buf);
+free(xc->temp_signal_value_buf);
 xc->temp_signal_value_buf = malloc(xc->longest_signal_value_len + 1);
 
 xc->var_count = xc->maxhandle + xc->num_alias;
@@ -2437,7 +2546,14 @@ if(sectype == FST_BL_ZWRAPPER)
 	char gz_membuf[FST_GZIO_LEN];
 	void *zhandle;
         int flen = strlen(xc->filename);
-        char *hf = calloc(1, flen + 16 + 32 + 1);
+        char *hf;
+
+	seclen = fstReaderUint64(xc->f);
+	uclen = fstReaderUint64(xc->f);
+
+	if(!seclen) return(0); /* not finished compressing, this is a failed read */
+
+        hf = calloc(1, flen + 16 + 32 + 1);
 
 	sprintf(hf, "%s.upk_%d_%p", xc->filename, getpid(), (void *)xc);
 	fcomp = fopen(hf, "w+b");
@@ -2450,11 +2566,6 @@ if(sectype == FST_BL_ZWRAPPER)
 	free(hf);
 #endif
 
-	seclen = fstReaderUint64(xc->f);
-	uclen = fstReaderUint64(xc->f);
-
-	if(!seclen) return(0); /* not finished compressing, this is a failed read */
-
 	fseeko(xc->f, 1+8+8, SEEK_SET);
 	fflush(xc->f);
 
@@ -2507,15 +2618,19 @@ while(blkpos < endfile)
 			xc->double_endian_match = (dcheck == FST_DOUBLE_ENDTEST);
 			if(!xc->double_endian_match)
 				{
-				unsigned char rvs_buf[8];
+				union	{
+  					unsigned char rvs_buf[8];
+  					double d;
+  					} vu;
+
 				unsigned char *dcheck_alias = (unsigned char *)&dcheck;
 				int rvs_idx;
 
 				for(rvs_idx=0;rvs_idx<8;rvs_idx++)
 					{
-					rvs_buf[rvs_idx] = dcheck_alias[7-rvs_idx];
+					vu.rvs_buf[rvs_idx] = dcheck_alias[7-rvs_idx];
 					}
-				if(*((double *)rvs_buf) != FST_DOUBLE_ENDTEST)
+				if(vu.d != FST_DOUBLE_ENDTEST)
 					{
 					break; /* either corrupt file or wrong architecture (offset +33 also functions as matchword) */
 					}
@@ -2563,7 +2678,7 @@ while(blkpos < endfile)
 			xc->maxhandle = fstReaderUint64(xc->f);
 			xc->longest_signal_value_len = 32; /* arbitrarily set at 32...this is much longer than an expanded double */
 
-			if(xc->process_mask) { free(xc->process_mask); }
+			free(xc->process_mask);
 			xc->process_mask = calloc(1, (xc->maxhandle+7)/8);
 
 			if(clen != uclen)
@@ -2589,9 +2704,9 @@ while(blkpos < endfile)
 				fstFread(ucdata, uclen, 1, xc->f);
 				}
 	
-			if(xc->signal_lens) free(xc->signal_lens);
+			free(xc->signal_lens);
 			xc->signal_lens = malloc(sizeof(uint32_t) * xc->maxhandle);
-			if(xc->signal_typs) free(xc->signal_typs);
+			free(xc->signal_typs);
 			xc->signal_typs = malloc(sizeof(unsigned char) * xc->maxhandle);
 	
 			for(i=0;i<xc->maxhandle;i++)
@@ -2618,7 +2733,7 @@ while(blkpos < endfile)
 					}
 				}
 
-			if(xc->temp_signal_value_buf) free(xc->temp_signal_value_buf);
+			free(xc->temp_signal_value_buf);
 			xc->temp_signal_value_buf = malloc(xc->longest_signal_value_len + 1); 
 	
 			free(ucdata);
@@ -2636,9 +2751,9 @@ while(blkpos < endfile)
 		uint64_t delta;
 
 		xc->num_blackouts = fstReaderVarint32(xc->f);
-		if(xc->blackout_times) free(xc->blackout_times);
+		free(xc->blackout_times);
 		xc->blackout_times = calloc(xc->num_blackouts, sizeof(uint64_t));
-		if(xc->blackout_activity) free(xc->blackout_activity);
+		free(xc->blackout_activity);
 		xc->blackout_activity = calloc(xc->num_blackouts, sizeof(unsigned char));
 
 		for(i=0;i<xc->num_blackouts;i++)
@@ -2719,11 +2834,11 @@ static void fstReaderDeallocateRvatData(void *ctx)
 struct fstReaderContext *xc = (struct fstReaderContext *)ctx;
 if(xc)
 	{
-	if(xc->rvat_chain_mem) { free(xc->rvat_chain_mem); xc->rvat_chain_mem = NULL; }
-	if(xc->rvat_frame_data) { free(xc->rvat_frame_data); xc->rvat_frame_data = NULL; }
-	if(xc->rvat_time_table) { free(xc->rvat_time_table); xc->rvat_time_table = NULL; }
-	if(xc->rvat_chain_table) { free(xc->rvat_chain_table); xc->rvat_chain_table = NULL; }
-	if(xc->rvat_chain_table_lengths) { free(xc->rvat_chain_table_lengths); xc->rvat_chain_table_lengths = NULL; }
+	free(xc->rvat_chain_mem); xc->rvat_chain_mem = NULL;
+	free(xc->rvat_frame_data); xc->rvat_frame_data = NULL;
+	free(xc->rvat_time_table); xc->rvat_time_table = NULL;
+	free(xc->rvat_chain_table); xc->rvat_chain_table = NULL;
+	free(xc->rvat_chain_table_lengths); xc->rvat_chain_table_lengths = NULL;
 
 	xc->rvat_data_valid = 0;
 	}
@@ -2738,15 +2853,15 @@ if(xc)
 	{
 	fstReaderDeallocateScopeData(xc);
 	fstReaderDeallocateRvatData(xc);
-	if(xc->rvat_sig_offs) { free(xc->rvat_sig_offs); xc->rvat_sig_offs = NULL; }
+	free(xc->rvat_sig_offs); xc->rvat_sig_offs = NULL;
 
-	if(xc->process_mask) { free(xc->process_mask); xc->process_mask = NULL; }
-	if(xc->blackout_times) { free(xc->blackout_times); xc->blackout_times = NULL; }
-	if(xc->blackout_activity) { free(xc->blackout_activity); xc->blackout_activity = NULL; }
-	if(xc->temp_signal_value_buf) { free(xc->temp_signal_value_buf); xc->temp_signal_value_buf = NULL; }
-	if(xc->signal_typs) { free(xc->signal_typs); xc->signal_typs = NULL; }
-	if(xc->signal_lens) { free(xc->signal_lens); xc->signal_lens = NULL; }
-	if(xc->filename) { free(xc->filename); xc->filename = NULL; }
+	free(xc->process_mask); xc->process_mask = NULL;
+	free(xc->blackout_times); xc->blackout_times = NULL;
+	free(xc->blackout_activity); xc->blackout_activity = NULL;
+	free(xc->temp_signal_value_buf); xc->temp_signal_value_buf = NULL;
+	free(xc->signal_typs); xc->signal_typs = NULL;
+	free(xc->signal_lens); xc->signal_lens = NULL;
+	free(xc->filename); xc->filename = NULL;
 
 	if(xc->fh) 
 		{ 
@@ -2786,7 +2901,7 @@ int fstReaderIterBlocks(void *ctx,
 {
 struct fstReaderContext *xc = (struct fstReaderContext *)ctx;
 
-uint64_t previous_time = ~0;
+uint64_t previous_time = UINT64_MAX;
 uint64_t *time_table = NULL;
 uint64_t tsec_nitems;
 int secnum = 0;
@@ -2915,7 +3030,7 @@ for(;;)
 		fstFread(ucdata, tsec_uclen, 1, xc->f);
 		}
 	
-	if(time_table) free(time_table);
+	free(time_table);
 	time_table = calloc(tsec_nitems, sizeof(uint64_t));
 	tpnt = ucdata;
 	tpval = 0;
@@ -3530,7 +3645,7 @@ if(chain_table)
 	free(chain_table_lengths);
 	}
 
-if(time_table) free(time_table);
+free(time_table);
 
 return(1);
 }
@@ -4092,5 +4207,5 @@ if(xc->signal_lens[facidx] == 1)
         }               
 }
 
-return(NULL);
+/* return(NULL); */
 }
