@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2007 Tony Bybell.
+ * Copyright (c) 2003-2009 Tony Bybell.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -197,23 +197,18 @@ return((m1<<24)|(m2<<16)|(m3<<8)|m4);
 
 static vztint32_t vzt_rd_get_v32(char **mmx)
 {
-union {
-  signed char **mm;
-  char **mmu;
-} u;
-
 signed char *c;
 signed char *beg;
 vztint32_t val;
+signed char **mm = (signed char **)mmx;
 
-u.mmu = mmx;
-c = *u.mm;
+c = *mm;
 beg = c;
 
 if(*c>=0)
 	{
 	while(*c>=0) c++;
-	*u.mm = c+1;
+	*mm = c+1;
 
 	val = (vztint32_t)(*c&0x7f);
 	do
@@ -224,7 +219,7 @@ if(*c>=0)
 	}
 	else
 	{
-	*u.mm = c+1;
+	*mm = c+1;
 	val = (vztint32_t)(*c&0x7f);
 	}
 
@@ -233,23 +228,18 @@ return(val);
 
 static vztint64_t vzt_rd_get_v64(char **mmx)
 {
-union {
-  signed char **mm;
-  char **mmu;
-} u;
-
 signed char *c;
 signed char *beg;
 vztint64_t val;
+signed char **mm = (signed char **)mmx;
 
-u.mmu = mmx;
-c = *u.mm;
+c = *mm;
 beg = c;
 
 if(*c>=0)
 	{
 	while(*c>=0) c++;
-	*u.mm = c+1;
+	*mm = c+1;
 
 	val = (vztint64_t)(*c&0x7f);
 	do
@@ -261,7 +251,7 @@ if(*c>=0)
 	else
 	{
 	val = (vztint64_t)(*c&0x7f);
-	*u.mm = c+1;
+	*mm = c+1;
 	}
 
 return(val);
@@ -445,7 +435,7 @@ b->multi_state = (num_bitplanes > 1);
 padskip = ((long)pnt)&3; pnt += (padskip) ? 4-padskip : 0; /* skip pad to next 4 byte boundary */
 b->vindex = (vztint32_t *)(pnt);
 
-if(*((int *)endian_word) == 0x01020304)	/* have to bswap the value changes on big endian machines... */
+if(*((int *)((void *)endian_word)) == 0x01020304) /* have to bswap the value changes on big endian machines... */
 	{
 	if(!b->rle)
 		{
@@ -1359,7 +1349,7 @@ return(blk);
 
 /****************************************************************************/
 
-static int vzt_rd_is_gzip_type(FILE *handle)
+static int vzt_rd_det_gzip_type(FILE *handle)
 {
 unsigned char cbuf[2] = { 0, 0 };
 
@@ -1367,7 +1357,17 @@ off_t off = ftello(handle);
 if(!fread(cbuf, 1, 2, handle)) { cbuf[0] = cbuf[1] = 0; }
 fseeko(handle, off, SEEK_SET);
 
-return((cbuf[0] == 0x1f) && (cbuf[1] == 0x8b));
+if((cbuf[0] == 0x1f) && (cbuf[1] == 0x8b))
+	{
+	return(VZT_RD_IS_GZ);
+	}
+
+if((cbuf[0] == 'z') && (cbuf[1] == '7'))
+	{
+	return(VZT_RD_IS_LZMA);
+	}
+
+return(VZT_RD_IS_BZ2);
 }
 
 /****************************************************************************/
@@ -1393,21 +1393,30 @@ if((!b->killed)&&(!b->mem))
 	{
 	b->mem = malloc(b->uncompressed_siz);
 
-	if(b->ztype)
+	switch(b->ztype)
 		{
-		zhandle = gzdopen(dup(fileno(handle)), "rb");
-		rc=gzread(zhandle, b->mem, b->uncompressed_siz);
-		gzclose(zhandle);
-		}
-		else
-		{
-		zhandle = BZ2_bzdopen(dup(fileno(handle)), "rb");
-		rc=BZ2_bzread(zhandle, b->mem, b->uncompressed_siz);
-		BZ2_bzclose(zhandle);
+		case VZT_RD_IS_GZ:
+			zhandle = gzdopen(dup(fileno(handle)), "rb");
+			rc=gzread(zhandle, b->mem, b->uncompressed_siz);
+			gzclose(zhandle);
+			break;
+
+		case VZT_RD_IS_BZ2:
+			zhandle = BZ2_bzdopen(dup(fileno(handle)), "rb");
+			rc=BZ2_bzread(zhandle, b->mem, b->uncompressed_siz);
+			BZ2_bzclose(zhandle);
+			break;
+
+		case VZT_RD_IS_LZMA:
+		default:
+			zhandle = LZMA_fdopen(dup(fileno(handle)), "rb");
+			rc=LZMA_read(zhandle, b->mem, b->uncompressed_siz);
+			LZMA_close(zhandle);
+			break;
 		}
 	if(rc!=b->uncompressed_siz)
 		{
-		fprintf(stderr, VZT_RDLOAD"short read on block %p %d vs %d (exp), ignoring\n", b, rc, b->uncompressed_siz);
+		fprintf(stderr, VZT_RDLOAD"short read on block %p %d vs "VZT_RD_LD" (exp), ignoring\n", (void *)b, rc, b->uncompressed_siz);
 		free(b->mem); b->mem=NULL;
 		b->short_read_ignore = 1;
 		}
@@ -1742,30 +1751,40 @@ if(!(lt->handle=fopen(name, "rb")))
 		rcf = fread(&lt->zfacgeometrysize, 4, 1, lt->handle);	lt->zfacgeometrysize = rcf ? vzt_rd_get_32(&lt->zfacgeometrysize,0) : 0;
 		rcf = fread(&lt->timescale, 1, 1, lt->handle);		if(!rcf) lt->timescale = 0; /* no swap necessary */
 
-		fprintf(stderr, VZT_RDLOAD"%d facilities\n", lt->numfacs);
+		fprintf(stderr, VZT_RDLOAD VZT_RD_LD" facilities\n", lt->numfacs);
 		pos = ftello(lt->handle);
 		/* fprintf(stderr, VZT_RDLOAD"gzip facnames start at pos %d (zsize=%d)\n", pos, lt->zfacnamesize); */
 
 		lt->process_mask = calloc(1, lt->numfacs/8+1);
 
-		if(vzt_rd_is_gzip_type(lt->handle))
+		switch(vzt_rd_det_gzip_type(lt->handle))
 			{
-			lt->zhandle = gzdopen(dup(fileno(lt->handle)), "rb");
-			m=(char *)malloc(lt->zfacname_predec_size);
-			rc=gzread(lt->zhandle, m, lt->zfacname_predec_size);
-			gzclose(lt->zhandle); lt->zhandle=NULL;
-			}
-			else
-			{
-			lt->zhandle = BZ2_bzdopen(dup(fileno(lt->handle)), "rb");
-			m=(char *)malloc(lt->zfacname_predec_size);
-			rc=BZ2_bzread(lt->zhandle, m, lt->zfacname_predec_size);
-			BZ2_bzclose(lt->zhandle); lt->zhandle=NULL;
-			}
+			case VZT_RD_IS_GZ:
+				lt->zhandle = gzdopen(dup(fileno(lt->handle)), "rb");
+				m=(char *)malloc(lt->zfacname_predec_size);
+				rc=gzread(lt->zhandle, m, lt->zfacname_predec_size);
+				gzclose(lt->zhandle); lt->zhandle=NULL;
+				break;
+
+			case VZT_RD_IS_BZ2:
+				lt->zhandle = BZ2_bzdopen(dup(fileno(lt->handle)), "rb");
+				m=(char *)malloc(lt->zfacname_predec_size);
+				rc=BZ2_bzread(lt->zhandle, m, lt->zfacname_predec_size);
+				BZ2_bzclose(lt->zhandle); lt->zhandle=NULL;
+				break;
+
+			case VZT_RD_IS_LZMA:
+			default:
+				lt->zhandle = LZMA_fdopen(dup(fileno(lt->handle)), "rb");
+				m=(char *)malloc(lt->zfacname_predec_size);
+				rc=LZMA_read(lt->zhandle, m, lt->zfacname_predec_size);
+				LZMA_close(lt->zhandle); lt->zhandle=NULL;
+				break;
+			}  
 
 		if(rc!=lt->zfacname_predec_size)
 			{
-			fprintf(stderr, VZT_RDLOAD"*** name section mangled %d (act) vs %d (exp)\n", rc, lt->zfacname_predec_size);
+			fprintf(stderr, VZT_RDLOAD"*** name section mangled %d (act) vs "VZT_RD_LD" (exp)\n", rc, lt->zfacname_predec_size);
 			free(m);
 
 			vzt_rd_close(lt);
@@ -1783,21 +1802,32 @@ if(!(lt->handle=fopen(name, "rb")))
 		fseeko(lt->handle, pos = pos+lt->zfacnamesize, SEEK_SET);
 		/* fprintf(stderr, VZT_RDLOAD"seeking to geometry at %d (0x%08x)\n", pos, pos); */
 
-		if(vzt_rd_is_gzip_type(lt->handle))
+		switch(vzt_rd_det_gzip_type(lt->handle))
 			{
-			lt->zhandle = gzdopen(dup(fileno(lt->handle)), "rb");
-			t = lt->numfacs * 4 * sizeof(vztint32_t);
-			m=(char *)malloc(t);				
-			rc=gzread(lt->zhandle, m, t);
-			gzclose(lt->zhandle); lt->zhandle=NULL;
-			}
-			else
-			{
-			lt->zhandle = BZ2_bzdopen(dup(fileno(lt->handle)), "rb");
-			t = lt->numfacs * 4 * sizeof(vztint32_t);
-			m=(char *)malloc(t);				
-			rc=BZ2_bzread(lt->zhandle, m, t);
-			BZ2_bzclose(lt->zhandle); lt->zhandle=NULL;
+			case VZT_RD_IS_GZ:
+				lt->zhandle = gzdopen(dup(fileno(lt->handle)), "rb");
+				t = lt->numfacs * 4 * sizeof(vztint32_t);
+				m=(char *)malloc(t);				
+				rc=gzread(lt->zhandle, m, t);
+				gzclose(lt->zhandle); lt->zhandle=NULL;
+				break;
+
+			case VZT_RD_IS_BZ2:
+				lt->zhandle = BZ2_bzdopen(dup(fileno(lt->handle)), "rb");
+				t = lt->numfacs * 4 * sizeof(vztint32_t);
+				m=(char *)malloc(t);				
+				rc=BZ2_bzread(lt->zhandle, m, t);
+				BZ2_bzclose(lt->zhandle); lt->zhandle=NULL;
+				break;
+
+			case VZT_RD_IS_LZMA:
+			default:
+				lt->zhandle = LZMA_fdopen(dup(fileno(lt->handle)), "rb");
+				t = lt->numfacs * 4 * sizeof(vztint32_t);
+				m=(char *)malloc(t);				
+				rc=LZMA_read(lt->zhandle, m, t);
+				LZMA_close(lt->zhandle); lt->zhandle=NULL;
+				break;
 			}
 
 		if(rc!=t)
@@ -1857,7 +1887,7 @@ if(!(lt->handle=fopen(name, "rb")))
 			vindex_offset += lt->len[lt->numrealfacs];
 			}
 		lt->total_values = vindex_offset;
-		fprintf(stderr, VZT_RDLOAD"Total value bits: %d\n", lt->total_values);
+		fprintf(stderr, VZT_RDLOAD"Total value bits: "VZT_RD_LD"\n", lt->total_values);
 
 		if(lt->numrealfacs > lt->numfacs) lt->numrealfacs = lt->numfacs;
 
@@ -1891,7 +1921,7 @@ if(!(lt->handle=fopen(name, "rb")))
 				b->end = tb;
 				}
 
-			b->ztype = vzt_rd_is_gzip_type(lt->handle);
+			b->ztype = vzt_rd_det_gzip_type(lt->handle);
 			/* fprintf(stderr, VZT_RDLOAD"block gzip start at pos %d (0x%08x)\n", pos, pos); */
 			if(pos>=fend)
 				{
@@ -2348,8 +2378,20 @@ return(rcval);
 }
 
 /*
- * $Id: vzt_read.c,v 1.4 2008/12/20 05:08:26 gtkwave Exp $
+ * $Id: vzt_read.c,v 1.8 2009/12/26 19:44:15 gtkwave Exp $
  * $Log: vzt_read.c,v $
+ * Revision 1.8  2009/12/26 19:44:15  gtkwave
+ * warnings fixes
+ *
+ * Revision 1.7  2009/12/24 20:08:15  gtkwave
+ * warnings fixes
+ *
+ * Revision 1.6  2009/04/27 21:26:34  gtkwave
+ * printf format string warning fixes
+ *
+ * Revision 1.5  2009/03/31 06:21:12  gtkwave
+ * added support for lzma
+ *
  * Revision 1.4  2008/12/20 05:08:26  gtkwave
  * -Wshadow warning cleanups
  *
