@@ -96,6 +96,8 @@ WV_MENU_EDFB,
 WV_MENU_EDFO,
 WV_MENU_EDFA,
 WV_MENU_EDRL,
+WV_MENU_EDR2BON,
+WV_MENU_EDR2BOFF,
 WV_MENU_EDFRJON,
 WV_MENU_EDFRJOFF,
 WV_MENU_EDFION,
@@ -107,6 +109,8 @@ WV_MENU_XLF_1,
 #if !defined __MINGW32__ && !defined _MSC_VER
 WV_MENU_XLP_0,
 WV_MENU_XLP_1,
+WV_MENU_TTXLP_0,
+WV_MENU_TTXLP_1,
 #endif
 WV_MENU_EDFAOFF,
 WV_MENU_EDFASTEP,
@@ -340,11 +344,22 @@ void read_save_helper(char *wname);
 
 void SetTraceScrollbarRowValue(int row, unsigned center);
 
+bvptr combine_traces(int direction, Trptr single_trace_only);
+
 #endif
 
 /*
- * $Id: menu.h,v 1.33 2010/02/24 18:06:14 gtkwave Exp $
+ * $Id: menu.h,v 1.36 2010/04/12 23:07:12 gtkwave Exp $
  * $Log: menu.h,v $
+ * Revision 1.36  2010/04/12 23:07:12  gtkwave
+ * add ability to make single signals transactions
+ *
+ * Revision 1.35  2010/03/31 15:42:47  gtkwave
+ * added preliminary transaction filter support
+ *
+ * Revision 1.34  2010/03/24 23:05:10  gtkwave
+ * added RealToBits menu option
+ *
  * Revision 1.33  2010/02/24 18:06:14  gtkwave
  * removed reduce single bit vectors
  *
