@@ -24,8 +24,8 @@ void init_proctrans_data(void)
 {
 int i;
 
-if(!GLOBALS->procsel_filter) { GLOBALS->procsel_filter = calloc_2(FILE_FILTER_MAX+1, sizeof(char *)); }
-if(!GLOBALS->proc_filter) { GLOBALS->proc_filter = calloc_2(FILE_FILTER_MAX+1, sizeof(struct pipe_ctx *)); }
+if(!GLOBALS->procsel_filter) { GLOBALS->procsel_filter = calloc_2(PROC_FILTER_MAX+1, sizeof(char *)); }
+if(!GLOBALS->proc_filter) { GLOBALS->proc_filter = calloc_2(PROC_FILTER_MAX+1, sizeof(struct pipe_ctx *)); }
 
 for(i=0;i<PROC_FILTER_MAX+1;i++)
 	{
@@ -36,21 +36,29 @@ for(i=0;i<PROC_FILTER_MAX+1;i++)
 
 void remove_all_proc_filters(void)
 {
-int i;
+struct Global *GLOBALS_cache = GLOBALS;
+int i, j;
 
-for(i=1;i<PROC_FILTER_MAX+1;i++)
+for(j=0;j<GLOBALS->num_notebook_pages;j++)
 	{
-	if(GLOBALS->proc_filter[i])
+	GLOBALS = (*GLOBALS->contexts)[j];
+
+	for(i=1;i<PROC_FILTER_MAX+1;i++)
 		{
-		pipeio_destroy(GLOBALS->proc_filter[i]);
-		GLOBALS->proc_filter[i] = NULL;
+		if(GLOBALS->proc_filter[i])
+			{
+			pipeio_destroy(GLOBALS->proc_filter[i]);
+			GLOBALS->proc_filter[i] = NULL;
+			}
+	
+		if(GLOBALS->procsel_filter[i])
+			{
+			free_2(GLOBALS->procsel_filter[i]);
+			GLOBALS->procsel_filter[i] = NULL;
+			}
 		}
 
-	if(GLOBALS->procsel_filter[i])
-		{
-		free_2(GLOBALS->procsel_filter[i]);
-		GLOBALS->procsel_filter[i] = NULL;
-		}
+	GLOBALS = GLOBALS_cache;
 	}
 }
 
@@ -71,7 +79,10 @@ wavearea_configure_event(GLOBALS->wavearea, NULL);
 }
 
 
-void remove_proc_filter(int which, int regen)
+/*
+ * this is likely obsolete
+ */
+static void remove_proc_filter(int which, int regen)
 {
 if(GLOBALS->proc_filter[which])
 	{
@@ -86,7 +97,7 @@ if(GLOBALS->proc_filter[which])
 }
 
 
-void load_proc_filter(int which, char *name)
+static void load_proc_filter(int which, char *name)
 {
 
   FILE *stream;
@@ -138,9 +149,11 @@ void load_proc_filter(int which, char *name)
   pclose(stream);
   free_2(cmd);
 
-  remove_proc_filter(which, 0); /* should never happen from GUI, but possible from save files or other weirdness */
-
-  GLOBALS->proc_filter[which] = pipeio_create(abs_path, arg);
+  /* remove_proc_filter(which, 0); ... should never happen from GUI, but perhaps possible from save files or other weirdness */
+  if(!GLOBALS->ttrans_filter[which])
+	{
+	GLOBALS->proc_filter[which] = pipeio_create(abs_path, arg);
+	}
 }
 
 void install_proc_filter(int which)
@@ -225,6 +238,7 @@ if(*GLOBALS->fileselbox_text)
 			if(!strcmp(GLOBALS->procsel_filter[i], *GLOBALS->fileselbox_text)) 
 				{
 				status_text("Filter already imported.\n");
+				if(GLOBALS->is_active_ptranslate_c_2) gdk_window_raise(GLOBALS->window_ptranslate_c_5->window);
 				return;
 				}
 			}
@@ -250,6 +264,8 @@ if(GLOBALS->proc_filter[GLOBALS->num_proc_filters])
 	{
 	GLOBALS->num_proc_filters--;
 	}
+
+if(GLOBALS->is_active_ptranslate_c_2) gdk_window_raise(GLOBALS->window_ptranslate_c_5->window);
 }
 
 static void add_filter_callback(GtkWidget *widget, GtkWidget *nothing)
@@ -431,8 +447,20 @@ if(GLOBALS->num_proc_filters < PROC_FILTER_MAX)
 #endif
 
 /*
- * $Id: ptranslate.c,v 1.7 2009/12/24 20:55:27 gtkwave Exp $
+ * $Id: ptranslate.c,v 1.11 2010/04/15 18:39:34 gtkwave Exp $
  * $Log: ptranslate.c,v $
+ * Revision 1.11  2010/04/15 18:39:34  gtkwave
+ * remove invocations of pipeio_destroy where unnecessary
+ *
+ * Revision 1.10  2010/04/15 01:55:03  gtkwave
+ * raise to front on filename select
+ *
+ * Revision 1.9  2010/03/31 15:42:47  gtkwave
+ * added preliminary transaction filter support
+ *
+ * Revision 1.8  2010/03/30 18:33:27  gtkwave
+ * fixed cut and paste errors from file to proc
+ *
  * Revision 1.7  2009/12/24 20:55:27  gtkwave
  * warnings cleanups
  *
