@@ -790,6 +790,7 @@ static struct rc_entry rcitems[]=
 
 static void vanilla_rc(void)
 {
+f_enable_fast_exit 	("on");
 f_splash_disable 	("off");
 f_zoom_pow10_snap	("on");
 f_hier_max_level	("1");
@@ -956,8 +957,11 @@ return;
 }
 
 /*
- * $Id: rc.c,v 1.23 2010/03/10 18:14:13 gtkwave Exp $
+ * $Id: rc.c,v 1.24 2010/05/06 15:57:52 gtkwave Exp $
  * $Log: rc.c,v $
+ * Revision 1.24  2010/05/06 15:57:52  gtkwave
+ * enable_fast_exit now is enabled by default
+ *
  * Revision 1.23  2010/03/10 18:14:13  gtkwave
  * Toggle Trace Hier fix (cache old value for more usability)
  *
