@@ -678,7 +678,7 @@ while(s)
 		UTimeType utt;
 		TimeType  tt;
 
-		h=bsearch_node(t->n.nd, basetime);
+		h=bsearch_node(t->n.nd, basetime - t->shift);
 		hp=GLOBALS->max_compare_index;
 		if((hp==&(t->n.nd->harray[1]))||(hp==&(t->n.nd->harray[0]))) return;
 		if(basetime == ((*hp)->time+GLOBALS->shift_timebase)) hp--;
@@ -694,7 +694,7 @@ while(s)
 		UTimeType utt;
 		TimeType  tt;
 
-		v=bsearch_vector(t->n.vec, basetime);
+		v=bsearch_vector(t->n.vec, basetime - t->shift);
 		vp=GLOBALS->vmax_compare_index;
 		if((vp==&(t->n.vec->vectors[1]))||(vp==&(t->n.vec->vectors[0]))) return;
 		if(basetime == ((*vp)->time+GLOBALS->shift_timebase)) vp--;
@@ -721,7 +721,7 @@ while(s)
 		UTimeType utt;
 		TimeType  tt;
 
-		h=bsearch_node(t->n.nd, basetime);
+		h=bsearch_node(t->n.nd, basetime - t->shift);
 		while(h->next && h->time==h->next->time) h=h->next;
 		if((whichpass)||(GLOBALS->tims.marker>=0)) h=h->next;
 		if(!h) return;
@@ -735,7 +735,7 @@ while(s)
 		UTimeType utt;
 		TimeType  tt;
 
-		v=bsearch_vector(t->n.vec, basetime);
+		v=bsearch_vector(t->n.vec, basetime - t->shift);
 		while(v->next && v->time==v->next->time) v=v->next;
 		if((whichpass)||(GLOBALS->tims.marker>=0)) v=v->next;
 		if(!v) return;
@@ -761,7 +761,7 @@ while(s)
 		{
 		if(strace_adjust(s->his.h->time,GLOBALS->shift_timebase)!=maxbase) 
 			{
-			s->his.h=bsearch_node(t->n.nd, maxbase);
+			s->his.h=bsearch_node(t->n.nd, maxbase - t->shift);
 			while(s->his.h->next && s->his.h->time==s->his.h->next->time) s->his.h=s->his.h->next;
 			}
 		if(t->flags&TR_INVERT)  
@@ -837,7 +837,7 @@ while(s)
 			{
 			if(strace_adjust(s->his.v->time,GLOBALS->shift_timebase)!=maxbase) 
 				{
-				s->his.v=bsearch_vector(t->n.vec, maxbase);
+				s->his.v=bsearch_vector(t->n.vec, maxbase - t->shift);
 				while(s->his.v->next && s->his.v->time==s->his.v->next->time) s->his.v=s->his.v->next;
 				}
 			chval=convert_ascii(t,s->his.v);
@@ -846,14 +846,14 @@ while(s)
 			{
 			if(strace_adjust(s->his.h->time,GLOBALS->shift_timebase)!=maxbase) 
 				{
-				s->his.h=bsearch_node(t->n.nd, maxbase);
+				s->his.h=bsearch_node(t->n.nd, maxbase - t->shift);
 				while(s->his.h->next && s->his.h->time==s->his.h->next->time) s->his.h=s->his.h->next;
 				}
 			if(s->his.h->flags&HIST_REAL)
 				{
 				if(!(s->his.h->flags&HIST_STRING))
 					{
-					chval=convert_ascii_real((double *)s->his.h->v.h_vector);
+					chval=convert_ascii_real(t, (double *)s->his.h->v.h_vector);
 					}
 					else
 					{
@@ -1069,7 +1069,7 @@ while(s)
 		UTimeType utt;
 		TimeType  tt;
 
-		h=bsearch_node(t->n.nd, basetime);
+		h=bsearch_node(t->n.nd, basetime - t->shift);
 		s->his.h=h;
 		while(h->time==h->next->time) h=h->next;
 		if((whichpass)||(notfirst)) h=h->next;
@@ -1083,7 +1083,7 @@ while(s)
 		UTimeType utt;
 		TimeType  tt;
 
-		v=bsearch_vector(t->n.vec, basetime);
+		v=bsearch_vector(t->n.vec, basetime - t->shift);
 		if((whichpass)||(notfirst)) v=v->next;
 		if(!v) return(MAX_HISTENT_TIME);
 		s->his.v=v;
@@ -1107,7 +1107,7 @@ while(s)
 		{
 		if(strace_adjust(s->his.h->time,GLOBALS->shift_timebase)!=maxbase) 
 			{
-			s->his.h=bsearch_node(t->n.nd, maxbase);
+			s->his.h=bsearch_node(t->n.nd, maxbase - t->shift);
 			while(s->his.h->next && s->his.h->time==s->his.h->next->time) s->his.h=s->his.h->next;
 			}
 		if(t->flags&TR_INVERT)  
@@ -1185,7 +1185,7 @@ while(s)
 			{
 			if(strace_adjust(s->his.v->time,GLOBALS->shift_timebase)!=maxbase) 
 				{
-				s->his.v=bsearch_vector(t->n.vec, maxbase);
+				s->his.v=bsearch_vector(t->n.vec, maxbase - t->shift);
 				while(s->his.v->next && s->his.v->time==s->his.v->next->time) s->his.v=s->his.v->next;
 				}
 			chval=convert_ascii(t,s->his.v);
@@ -1194,14 +1194,14 @@ while(s)
 			{
 			if(strace_adjust(s->his.h->time,GLOBALS->shift_timebase)!=maxbase) 
 				{
-				s->his.h=bsearch_node(t->n.nd, maxbase);
+				s->his.h=bsearch_node(t->n.nd, maxbase - t->shift);
 				while(s->his.h->next && s->his.h->time==s->his.h->next->time) s->his.h=s->his.h->next;
 				}
 			if(s->his.h->flags&HIST_REAL)
 				{
 				if(!(s->his.h->flags&HIST_STRING))
 					{
-					chval=convert_ascii_real((double *)s->his.h->v.h_vector);
+					chval=convert_ascii_real(t, (double *)s->his.h->v.h_vector);
 					}
 					else
 					{
@@ -1647,7 +1647,7 @@ if(GLOBALS->strace_ctx->timearray)
 				mprintf("#{%s}",t->name);
 
 				nodes=t->n.vec->bits->nodes;
-				for(i=0;i<t->n.vec->nbits;i++)
+				for(i=0;i<t->n.vec->bits->nnbits;i++)
 					{
 					if(nodes[i]->expansion)
 						{
@@ -1695,8 +1695,17 @@ if(GLOBALS->strace_ctx->timearray)
 }
 
 /*
- * $Id: strace.c,v 1.18 2010/03/14 07:09:49 gtkwave Exp $
+ * $Id: strace.c,v 1.21 2010/04/01 03:10:58 gtkwave Exp $
  * $Log: strace.c,v $
+ * Revision 1.21  2010/04/01 03:10:58  gtkwave
+ * time warp fixes
+ *
+ * Revision 1.20  2010/03/31 20:41:03  gtkwave
+ * nbits versus nnbits fix
+ *
+ * Revision 1.19  2010/03/24 23:05:10  gtkwave
+ * added RealToBits menu option
+ *
  * Revision 1.18  2010/03/14 07:09:49  gtkwave
  * removed ExtNode and merged with Node
  *
