@@ -49,45 +49,38 @@ else
 /*
  * generate a vcd identifier for a given facindx
  */
-static char *vcdid(int value)
+static char *vcdid(int value, int export_typ)
 {
 char *pnt = GLOBALS->buf_vcd_saver_c_3;
 int i, vmod;
 
-value++;
-for(i=0;;i++)
-        {
-        if((vmod = (value % 94)))
-                {
-                *(pnt++) = (char)(vmod + 32);
-                }   
-                else
-                {
-                *(pnt++) = '~'; value -= 94;
-                }
-        value = value / 94;  
-        if(!value) { break; }
-        }
+if(export_typ != WAVE_EXPORT_TRANS)
+	{
+	value++;
+	for(i=0;;i++)
+	        {
+	        if((vmod = (value % 94)))
+	                {
+	                *(pnt++) = (char)(vmod + 32);
+	                }   
+	                else
+	                {
+	                *(pnt++) = '~'; value -= 94;
+	                }
+	        value = value / 94;  
+	        if(!value) { break; }
+	        }
+
+	*pnt = 0;   
+	}
+	else
+	{
+	sprintf(pnt, "%d", value);	
+	}
 
-*pnt = 0;   
 return(GLOBALS->buf_vcd_saver_c_3);
 }
 
-/*
-static char *vcdid(int value)
-{
-int i;
-                                         
-for(i=0;i<15;i++)
-        {
-        GLOBALS->buf_vcd_saver_c_3[i]=(char)((value%94)+33);
-        value=value/94;
-        if(!value) {GLOBALS->buf_vcd_saver_c_3[i+1]=0; break;}
-        }
-                    
-return(GLOBALS->buf_vcd_saver_c_3);
-}
-*/
 
 static char *vcd_truncate_bitvec(char *s)
 {
@@ -324,9 +317,9 @@ for(;;)
 /*
  * mainline
  */ 
-int save_nodes_to_export(const char *fname, int export_typ)
+int save_nodes_to_export_generic(FILE *trans_file, Trptr trans_head, const char *fname, int export_typ)
 {
-Trptr t = GLOBALS->traces.first;
+Trptr t = trans_head ? trans_head : GLOBALS->traces.first;
 int nodecnt = 0;
 vcdsav_Tree *vt = NULL;
 vcdsav_Tree **hp_clone = GLOBALS->hp_vcd_saver_c_1;
@@ -342,6 +335,7 @@ int max_len = 1;
 char *row_data = NULL;
 struct lt_trace *lt = NULL;
 int lxt = (export_typ == WAVE_EXPORT_LXT);
+int seqn = 0;
 
 if(export_typ == WAVE_EXPORT_TIM)
 	{
@@ -359,7 +353,15 @@ if(lxt)
 	}
 	else
 	{
-	GLOBALS->f_vcd_saver_c_1 = fopen(fname, "wb");
+	if(export_typ != WAVE_EXPORT_TRANS)
+		{
+		GLOBALS->f_vcd_saver_c_1 = fopen(fname, "wb");
+		}
+		else
+		{
+		GLOBALS->f_vcd_saver_c_1 = trans_file;
+		}
+
 	if(!GLOBALS->f_vcd_saver_c_1)
 		{
 		return(VCDSAV_FILE_ERROR);
@@ -397,7 +399,7 @@ while(t)
 			bptr bt = b->bits;
 			if(bt)
 				{
-				for(i=0;i<bt->nbits;i++)
+				for(i=0;i<bt->nnbits;i++)
 					{
 					if(bt->nodes[i]) 
 						{
@@ -423,6 +425,12 @@ while(t)
 			}
 		}
 
+
+	if(export_typ == WAVE_EXPORT_TRANS)
+		{
+		break;
+		}
+
 	if(!strace_append)
 		{
 		t=t->t_next;
@@ -486,14 +494,30 @@ if(lxt)
 	}
 	else
 	{
-	time(&walltime);
-	fprintf(GLOBALS->f_vcd_saver_c_1, "$date\n");
-	fprintf(GLOBALS->f_vcd_saver_c_1, "\t%s",asctime(localtime(&walltime)));
-	fprintf(GLOBALS->f_vcd_saver_c_1, "$end\n");
-	fprintf(GLOBALS->f_vcd_saver_c_1, "$version\n\t"WAVE_VERSION_INFO"\n$end\n");
-	fprintf(GLOBALS->f_vcd_saver_c_1, "$timescale\n\t%d%c%s\n$end\n", (int)GLOBALS->time_scale, GLOBALS->time_dimension, (GLOBALS->time_dimension=='s') ? "" : "s");
+	if(export_typ != WAVE_EXPORT_TRANS)
+		{
+		time(&walltime);
+		fprintf(GLOBALS->f_vcd_saver_c_1, "$date\n");
+		fprintf(GLOBALS->f_vcd_saver_c_1, "\t%s",asctime(localtime(&walltime)));
+		fprintf(GLOBALS->f_vcd_saver_c_1, "$end\n");
+		fprintf(GLOBALS->f_vcd_saver_c_1, "$version\n\t"WAVE_VERSION_INFO"\n$end\n");
+		fprintf(GLOBALS->f_vcd_saver_c_1, "$timescale\n\t%d%c%s\n$end\n", (int)GLOBALS->time_scale, GLOBALS->time_dimension, (GLOBALS->time_dimension=='s') ? "" : "s");
+		}
+		else
+		{
+		fprintf(GLOBALS->f_vcd_saver_c_1, "$comment data_start %p $end\n", trans_head); /* arbitrary hex identifier */
+		fprintf(GLOBALS->f_vcd_saver_c_1, "$comment name %s $end\n", trans_head->name ? trans_head->name : "UNKNOWN");
+		fprintf(GLOBALS->f_vcd_saver_c_1, "$timescale %d%c%s $end\n", (int)GLOBALS->time_scale, GLOBALS->time_dimension, (GLOBALS->time_dimension=='s') ? "" : "s");
+		fprintf(GLOBALS->f_vcd_saver_c_1, "$comment min_time "TTFormat" $end\n", GLOBALS->min_time / GLOBALS->time_scale);
+		fprintf(GLOBALS->f_vcd_saver_c_1, "$comment max_time "TTFormat" $end\n", GLOBALS->max_time / GLOBALS->time_scale);
+		}
 	}
 
+if(export_typ == WAVE_EXPORT_TRANS)
+	{
+        fprintf(GLOBALS->f_vcd_saver_c_1, "$comment max_seqn %d $end\n", nodecnt);
+        }
+
 /* write out netnames here ... */
 hp_clone = GLOBALS->hp_vcd_saver_c_1 = calloc_2(nodecnt, sizeof(vcdsav_Tree *));
 recurse_build(vt, &hp_clone);
@@ -504,6 +528,11 @@ for(i=0;i<nodecnt;i++)
 	char *hname = hier_decompress_flagged(GLOBALS->hp_vcd_saver_c_1[i]->item->nname, &was_packed);
 	char *netname = lxt ? hname : output_hier(hname);
 
+	if(export_typ == WAVE_EXPORT_TRANS)
+		{
+	        fprintf(GLOBALS->f_vcd_saver_c_1, "$comment seqn %d %s $end\n", GLOBALS->hp_vcd_saver_c_1[i]->val, hname);
+	        }
+
 	if(GLOBALS->hp_vcd_saver_c_1[i]->flags & (HIST_REAL|HIST_STRING))
 		{
 		if(lxt)
@@ -512,7 +541,7 @@ for(i=0;i<nodecnt;i++)
 			}
 			else
 			{
-			fprintf(GLOBALS->f_vcd_saver_c_1, "$var real 1 %s %s $end\n", vcdid(GLOBALS->hp_vcd_saver_c_1[i]->val), netname);
+			fprintf(GLOBALS->f_vcd_saver_c_1, "$var real 1 %s %s $end\n", vcdid(GLOBALS->hp_vcd_saver_c_1[i]->val, export_typ), netname);
 			}
 		}
 		else
@@ -538,7 +567,7 @@ for(i=0;i<nodecnt;i++)
 				}
 				else
 				{
-				fprintf(GLOBALS->f_vcd_saver_c_1, "$var wire 1 %s %s $end\n", vcdid(GLOBALS->hp_vcd_saver_c_1[i]->val), netname);
+				fprintf(GLOBALS->f_vcd_saver_c_1, "$var wire 1 %s %s $end\n", vcdid(GLOBALS->hp_vcd_saver_c_1[i]->val, export_typ), netname);
 				}
 			}
 			else
@@ -550,7 +579,7 @@ for(i=0;i<nodecnt;i++)
 				}
 				else
 				{
-				fprintf(GLOBALS->f_vcd_saver_c_1, "$var wire %d %s %s $end\n", len, vcdid(GLOBALS->hp_vcd_saver_c_1[i]->val), netname);
+				fprintf(GLOBALS->f_vcd_saver_c_1, "$var wire %d %s %s $end\n", len, vcdid(GLOBALS->hp_vcd_saver_c_1[i]->val, export_typ), netname);
 				}
 			GLOBALS->hp_vcd_saver_c_1[i]->len = len;
 			if(len > max_len) max_len = len;
@@ -621,7 +650,7 @@ for(;;)
 					}
 					else
 					{
-					fprintf(GLOBALS->f_vcd_saver_c_1, "s%s %s\n", vec, vcdid(GLOBALS->hp_vcd_saver_c_1[0]->val));
+					fprintf(GLOBALS->f_vcd_saver_c_1, "s%s %s\n", vec, vcdid(GLOBALS->hp_vcd_saver_c_1[0]->val, export_typ));
 					}
 				}
 				else
@@ -644,7 +673,7 @@ for(;;)
 					}
 					else
 					{
-					fprintf(GLOBALS->f_vcd_saver_c_1, "r%.16g %s\n", value, vcdid(GLOBALS->hp_vcd_saver_c_1[0]->val));	
+					fprintf(GLOBALS->f_vcd_saver_c_1, "r%.16g %s\n", value, vcdid(GLOBALS->hp_vcd_saver_c_1[0]->val, export_typ));	
 					}
 				}	
 			}
@@ -673,7 +702,7 @@ for(;;)
 				}
 				else
 				{
-				fprintf(GLOBALS->f_vcd_saver_c_1, "b%s %s\n", vcd_truncate_bitvec(row_data), vcdid(GLOBALS->hp_vcd_saver_c_1[0]->val));
+				fprintf(GLOBALS->f_vcd_saver_c_1, "b%s %s\n", vcd_truncate_bitvec(row_data), vcdid(GLOBALS->hp_vcd_saver_c_1[0]->val, export_typ));
 				}
 			}
 		else
@@ -687,7 +716,7 @@ for(;;)
 				}
 				else
 				{
-				fprintf(GLOBALS->f_vcd_saver_c_1, "%c%s\n", analyzer_demang(lxt, GLOBALS->hp_vcd_saver_c_1[0]->hist->v.h_val), vcdid(GLOBALS->hp_vcd_saver_c_1[0]->val));
+				fprintf(GLOBALS->f_vcd_saver_c_1, "%c%s\n", analyzer_demang(lxt, GLOBALS->hp_vcd_saver_c_1[0]->hist->v.h_val), vcdid(GLOBALS->hp_vcd_saver_c_1[0]->val, export_typ));
 				}
 			}
 		}
@@ -722,12 +751,35 @@ if(lxt)
 	}
 	else
 	{
-	fclose(GLOBALS->f_vcd_saver_c_1); GLOBALS->f_vcd_saver_c_1 = NULL;
+	if(export_typ != WAVE_EXPORT_TRANS)
+		{
+		fclose(GLOBALS->f_vcd_saver_c_1); 
+		}
+		else
+		{
+		fprintf(GLOBALS->f_vcd_saver_c_1, "$comment data_end %p $end\n", trans_head); /* arbitrary hex identifier */
+		fflush(GLOBALS->f_vcd_saver_c_1);
+		}
+
+	GLOBALS->f_vcd_saver_c_1 = NULL;
 	}
 
 return(VCDSAV_OK);
 }
 
+
+
+int save_nodes_to_export(const char *fname, int export_typ)
+{
+return(save_nodes_to_export_generic(NULL, NULL, fname, export_typ));
+}
+
+int save_nodes_to_trans(FILE *trans, Trptr t)
+{
+return(save_nodes_to_export_generic(trans, t, NULL, WAVE_EXPORT_TRANS));
+}
+
+
 /************************ scopenav ************************/
 
 struct namehier
@@ -1058,7 +1110,7 @@ if(h->flags&HIST_REAL)
 	{
         if(!(h->flags&HIST_STRING))
         	{               
-                ascii=convert_ascii_real((double *)h->v.h_vector);
+                ascii=convert_ascii_real(t, (double *)h->v.h_vector);
                 }
                 else
                 {
@@ -1465,8 +1517,17 @@ return(errno ? VCDSAV_FILE_ERROR : VCDSAV_OK);
 }
 
 /*
- * $Id: vcd_saver.c,v 1.13 2010/03/14 07:09:49 gtkwave Exp $
+ * $Id: vcd_saver.c,v 1.16 2010/04/01 20:07:35 gtkwave Exp $
  * $Log: vcd_saver.c,v $
+ * Revision 1.16  2010/04/01 20:07:35  gtkwave
+ * timescale multiplier fix for transactions
+ *
+ * Revision 1.15  2010/03/31 15:42:47  gtkwave
+ * added preliminary transaction filter support
+ *
+ * Revision 1.14  2010/03/24 23:05:10  gtkwave
+ * added RealToBits menu option
+ *
  * Revision 1.13  2010/03/14 07:09:49  gtkwave
  * removed ExtNode and merged with Node
  *
